==> adyen-java-api-library-2.7.2-sources.jar: com/adyen/model/marketpay/notification/AccountHolderCreatedNotification.java <==
/*
 *                       ######
 *                       ######
 * ############    ####( ######  #####. ######  ############   ############
 * #############  #####( ######  #####. ######  #############  #############
 *        ######  #####( ######  #####. ######  #####  ######  #####  ######
 * ###### ######  #####( ######  #####. ######  #####  #####   #####  ######
 * ###### ######  #####( ######  #####. ######  #####          #####  ######
 * #############  #############  #############  #############  #####  ######
 *  ############   ############  #############   ############  #####  ######
 *                                      ######
 *                               #############
 *                               ############
 *
 * Adyen Java API Library
 *
 * Copyright (c) 2017 Adyen B.V.
 * This file is open source and available under the MIT license.
 * See the LICENSE file for more info.
 */

package com.adyen.model.marketpay.notification;

import com.adyen.model.marketpay.CreateAccountHolderResponse;
import com.google.gson.annotations.SerializedName;

public class AccountHolderCreatedNotification extends GenericNotification {
    @SerializedName("content")
    private CreateAccountHolderResponse content;

    public CreateAccountHolderResponse getContent() {
        return content;
    }

    public void setContent(CreateAccountHolderResponse content) {
        this.content = content;
    }

    @Override
    public String toString() {
        return "AccountHolderCreatedNotification{" + "content=" + content + '}';
    }
}

==> adyen-java-api-library-13.0.0-sources.jar: com/adyen/model/marketpay/notification/AccountHolderCreatedNotification.java <==
/*
 *                       ######
 *                       ######
 * ############    ####( ######  #####. ######  ############   ############
 * #############  #####( ######  #####. ######  #############  #############
 *        ######  #####( ######  #####. ######  #####  ######  #####  ######
 * ###### ######  #####( ######  #####. ######  #####  #####   #####  ######
 * ###### ######  #####( ######  #####. ######  #####          #####  ######
 * #############  #############  #############  #############  #####  ######
 *  ############   ############  #############   ############  #####  ######
 *                                      ######
 *                               #############
 *                               ############
 *
 * Adyen Java API Library
 *
 * Copyright (c) 2017 Adyen B.V.
 * This file is open source and available under the MIT license.
 * See the LICENSE file for more info.
 */

package com.adyen.model.marketpay.notification;

import com.adyen.model.marketpay.CreateAccountHolderResponse;
import com.google.gson.annotations.SerializedName;

public class AccountHolderCreatedNotification extends GenericNotification {
    @SerializedName("content")
    private CreateAccountHolderResponse content;

    public CreateAccountHolderResponse getContent() {
        return content;
    }

    public void setContent(CreateAccountHolderResponse content) {
        this.content = content;
    }

    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder("AccountHolderCreatedNotification{");
        sb.append("content=").append(content);
        sb.append('}');
        return sb.toString();
    }
}
